Documentation
¶
Index ¶
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) CreateTrail(request *CreateTrailRequest) (response *CreateTrailResponse, err error)
- func (client *Client) CreateTrailWithCallback(request *CreateTrailRequest, ...) <-chan int
- func (client *Client) CreateTrailWithChan(request *CreateTrailRequest) (<-chan *CreateTrailResponse, <-chan error)
- func (client *Client) DeleteTrail(request *DeleteTrailRequest) (response *DeleteTrailResponse, err error)
- func (client *Client) DeleteTrailWithCallback(request *DeleteTrailRequest, ...) <-chan int
- func (client *Client) DeleteTrailWithChan(request *DeleteTrailRequest) (<-chan *DeleteTrailResponse, <-chan error)
- func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
- func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, ...) <-chan int
- func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
- func (client *Client) DescribeTrails(request *DescribeTrailsRequest) (response *DescribeTrailsResponse, err error)
- func (client *Client) DescribeTrailsWithCallback(request *DescribeTrailsRequest, ...) <-chan int
- func (client *Client) DescribeTrailsWithChan(request *DescribeTrailsRequest) (<-chan *DescribeTrailsResponse, <-chan error)
- func (client *Client) GetTrailStatus(request *GetTrailStatusRequest) (response *GetTrailStatusResponse, err error)
- func (client *Client) GetTrailStatusWithCallback(request *GetTrailStatusRequest, ...) <-chan int
- func (client *Client) GetTrailStatusWithChan(request *GetTrailStatusRequest) (<-chan *GetTrailStatusResponse, <-chan error)
- func (client *Client) LookupEvents(request *LookupEventsRequest) (response *LookupEventsResponse, err error)
- func (client *Client) LookupEventsWithCallback(request *LookupEventsRequest, ...) <-chan int
- func (client *Client) LookupEventsWithChan(request *LookupEventsRequest) (<-chan *LookupEventsResponse, <-chan error)
- func (client *Client) StartLogging(request *StartLoggingRequest) (response *StartLoggingResponse, err error)
- func (client *Client) StartLoggingWithCallback(request *StartLoggingRequest, ...) <-chan int
- func (client *Client) StartLoggingWithChan(request *StartLoggingRequest) (<-chan *StartLoggingResponse, <-chan error)
- func (client *Client) StopLogging(request *StopLoggingRequest) (response *StopLoggingResponse, err error)
- func (client *Client) StopLoggingWithCallback(request *StopLoggingRequest, ...) <-chan int
- func (client *Client) StopLoggingWithChan(request *StopLoggingRequest) (<-chan *StopLoggingResponse, <-chan error)
- func (client *Client) UpdateTrail(request *UpdateTrailRequest) (response *UpdateTrailResponse, err error)
- func (client *Client) UpdateTrailWithCallback(request *UpdateTrailRequest, ...) <-chan int
- func (client *Client) UpdateTrailWithChan(request *UpdateTrailRequest) (<-chan *UpdateTrailResponse, <-chan error)
- type CreateTrailRequest
- type CreateTrailResponse
- type DeleteTrailRequest
- type DeleteTrailResponse
- type DescribeRegionsRequest
- type DescribeRegionsResponse
- type DescribeTrailsRequest
- type DescribeTrailsResponse
- type Events
- type GetTrailStatusRequest
- type GetTrailStatusResponse
- type LookupEventsRequest
- type LookupEventsResponse
- type Region
- type RegionItem
- type Regions
- type StartLoggingRequest
- type StartLoggingResponse
- type StopLoggingRequest
- type StopLoggingResponse
- type TrailList
- type TrailListItem
- type UpdateTrailRequest
- type UpdateTrailResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://help.aliyun.com/document_detail/66217.html
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://help.aliyun.com/document_detail/66223.html
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://help.aliyun.com/document_detail/66222.html
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair attention: rsa key pair auth is only Japan regions available
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://help.aliyun.com/document_detail/66222.html
func (*Client) CreateTrail ¶
func (client *Client) CreateTrail(request *CreateTrailRequest) (response *CreateTrailResponse, err error)
CreateTrail invokes the actiontrail.CreateTrail API synchronously api document: https://help.aliyun.com/api/actiontrail/createtrail.html
func (*Client) CreateTrailWithCallback ¶
func (client *Client) CreateTrailWithCallback(request *CreateTrailRequest, callback func(response *CreateTrailResponse, err error)) <-chan int
CreateTrailWithCallback invokes the actiontrail.CreateTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/createtrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateTrailWithChan ¶
func (client *Client) CreateTrailWithChan(request *CreateTrailRequest) (<-chan *CreateTrailResponse, <-chan error)
CreateTrailWithChan invokes the actiontrail.CreateTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/createtrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteTrail ¶
func (client *Client) DeleteTrail(request *DeleteTrailRequest) (response *DeleteTrailResponse, err error)
DeleteTrail invokes the actiontrail.DeleteTrail API synchronously api document: https://help.aliyun.com/api/actiontrail/deletetrail.html
func (*Client) DeleteTrailWithCallback ¶
func (client *Client) DeleteTrailWithCallback(request *DeleteTrailRequest, callback func(response *DeleteTrailResponse, err error)) <-chan int
DeleteTrailWithCallback invokes the actiontrail.DeleteTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/deletetrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteTrailWithChan ¶
func (client *Client) DeleteTrailWithChan(request *DeleteTrailRequest) (<-chan *DeleteTrailResponse, <-chan error)
DeleteTrailWithChan invokes the actiontrail.DeleteTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/deletetrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRegions ¶
func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
DescribeRegions invokes the actiontrail.DescribeRegions API synchronously api document: https://help.aliyun.com/api/actiontrail/describeregions.html
func (*Client) DescribeRegionsWithCallback ¶
func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, callback func(response *DescribeRegionsResponse, err error)) <-chan int
DescribeRegionsWithCallback invokes the actiontrail.DescribeRegions API asynchronously api document: https://help.aliyun.com/api/actiontrail/describeregions.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRegionsWithChan ¶
func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
DescribeRegionsWithChan invokes the actiontrail.DescribeRegions API asynchronously api document: https://help.aliyun.com/api/actiontrail/describeregions.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeTrails ¶
func (client *Client) DescribeTrails(request *DescribeTrailsRequest) (response *DescribeTrailsResponse, err error)
DescribeTrails invokes the actiontrail.DescribeTrails API synchronously api document: https://help.aliyun.com/api/actiontrail/describetrails.html
func (*Client) DescribeTrailsWithCallback ¶
func (client *Client) DescribeTrailsWithCallback(request *DescribeTrailsRequest, callback func(response *DescribeTrailsResponse, err error)) <-chan int
DescribeTrailsWithCallback invokes the actiontrail.DescribeTrails API asynchronously api document: https://help.aliyun.com/api/actiontrail/describetrails.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeTrailsWithChan ¶
func (client *Client) DescribeTrailsWithChan(request *DescribeTrailsRequest) (<-chan *DescribeTrailsResponse, <-chan error)
DescribeTrailsWithChan invokes the actiontrail.DescribeTrails API asynchronously api document: https://help.aliyun.com/api/actiontrail/describetrails.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) GetTrailStatus ¶
func (client *Client) GetTrailStatus(request *GetTrailStatusRequest) (response *GetTrailStatusResponse, err error)
GetTrailStatus invokes the actiontrail.GetTrailStatus API synchronously api document: https://help.aliyun.com/api/actiontrail/gettrailstatus.html
func (*Client) GetTrailStatusWithCallback ¶
func (client *Client) GetTrailStatusWithCallback(request *GetTrailStatusRequest, callback func(response *GetTrailStatusResponse, err error)) <-chan int
GetTrailStatusWithCallback invokes the actiontrail.GetTrailStatus API asynchronously api document: https://help.aliyun.com/api/actiontrail/gettrailstatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) GetTrailStatusWithChan ¶
func (client *Client) GetTrailStatusWithChan(request *GetTrailStatusRequest) (<-chan *GetTrailStatusResponse, <-chan error)
GetTrailStatusWithChan invokes the actiontrail.GetTrailStatus API asynchronously api document: https://help.aliyun.com/api/actiontrail/gettrailstatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) LookupEvents ¶
func (client *Client) LookupEvents(request *LookupEventsRequest) (response *LookupEventsResponse, err error)
LookupEvents invokes the actiontrail.LookupEvents API synchronously api document: https://help.aliyun.com/api/actiontrail/lookupevents.html
func (*Client) LookupEventsWithCallback ¶
func (client *Client) LookupEventsWithCallback(request *LookupEventsRequest, callback func(response *LookupEventsResponse, err error)) <-chan int
LookupEventsWithCallback invokes the actiontrail.LookupEvents API asynchronously api document: https://help.aliyun.com/api/actiontrail/lookupevents.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) LookupEventsWithChan ¶
func (client *Client) LookupEventsWithChan(request *LookupEventsRequest) (<-chan *LookupEventsResponse, <-chan error)
LookupEventsWithChan invokes the actiontrail.LookupEvents API asynchronously api document: https://help.aliyun.com/api/actiontrail/lookupevents.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) StartLogging ¶
func (client *Client) StartLogging(request *StartLoggingRequest) (response *StartLoggingResponse, err error)
StartLogging invokes the actiontrail.StartLogging API synchronously api document: https://help.aliyun.com/api/actiontrail/startlogging.html
func (*Client) StartLoggingWithCallback ¶
func (client *Client) StartLoggingWithCallback(request *StartLoggingRequest, callback func(response *StartLoggingResponse, err error)) <-chan int
StartLoggingWithCallback invokes the actiontrail.StartLogging API asynchronously api document: https://help.aliyun.com/api/actiontrail/startlogging.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) StartLoggingWithChan ¶
func (client *Client) StartLoggingWithChan(request *StartLoggingRequest) (<-chan *StartLoggingResponse, <-chan error)
StartLoggingWithChan invokes the actiontrail.StartLogging API asynchronously api document: https://help.aliyun.com/api/actiontrail/startlogging.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) StopLogging ¶
func (client *Client) StopLogging(request *StopLoggingRequest) (response *StopLoggingResponse, err error)
StopLogging invokes the actiontrail.StopLogging API synchronously api document: https://help.aliyun.com/api/actiontrail/stoplogging.html
func (*Client) StopLoggingWithCallback ¶
func (client *Client) StopLoggingWithCallback(request *StopLoggingRequest, callback func(response *StopLoggingResponse, err error)) <-chan int
StopLoggingWithCallback invokes the actiontrail.StopLogging API asynchronously api document: https://help.aliyun.com/api/actiontrail/stoplogging.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) StopLoggingWithChan ¶
func (client *Client) StopLoggingWithChan(request *StopLoggingRequest) (<-chan *StopLoggingResponse, <-chan error)
StopLoggingWithChan invokes the actiontrail.StopLogging API asynchronously api document: https://help.aliyun.com/api/actiontrail/stoplogging.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateTrail ¶
func (client *Client) UpdateTrail(request *UpdateTrailRequest) (response *UpdateTrailResponse, err error)
UpdateTrail invokes the actiontrail.UpdateTrail API synchronously api document: https://help.aliyun.com/api/actiontrail/updatetrail.html
func (*Client) UpdateTrailWithCallback ¶
func (client *Client) UpdateTrailWithCallback(request *UpdateTrailRequest, callback func(response *UpdateTrailResponse, err error)) <-chan int
UpdateTrailWithCallback invokes the actiontrail.UpdateTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/updatetrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateTrailWithChan ¶
func (client *Client) UpdateTrailWithChan(request *UpdateTrailRequest) (<-chan *UpdateTrailResponse, <-chan error)
UpdateTrailWithChan invokes the actiontrail.UpdateTrail API asynchronously api document: https://help.aliyun.com/api/actiontrail/updatetrail.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type CreateTrailRequest ¶
type CreateTrailRequest struct {
*requests.RpcRequest
SlsProjectArn string `position:"Query" name:"SlsProjectArn"`
SlsWriteRoleArn string `position:"Query" name:"SlsWriteRoleArn"`
RoleName string `position:"Query" name:"RoleName"`
Name string `position:"Query" name:"Name"`
OssBucketName string `position:"Query" name:"OssBucketName"`
OssKeyPrefix string `position:"Query" name:"OssKeyPrefix"`
EventRW string `position:"Query" name:"EventRW"`
}
CreateTrailRequest is the request struct for api CreateTrail
func CreateCreateTrailRequest ¶
func CreateCreateTrailRequest() (request *CreateTrailRequest)
CreateCreateTrailRequest creates a request to invoke CreateTrail API
type CreateTrailResponse ¶
type CreateTrailResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Name string `json:"Name" xml:"Name"`
HomeRegion string `json:"HomeRegion" xml:"HomeRegion"`
OssBucketName string `json:"OssBucketName" xml:"OssBucketName"`
OssKeyPrefix string `json:"OssKeyPrefix" xml:"OssKeyPrefix"`
RoleName string `json:"RoleName" xml:"RoleName"`
SlsProjectArn string `json:"SlsProjectArn" xml:"SlsProjectArn"`
SlsWriteRoleArn string `json:"SlsWriteRoleArn" xml:"SlsWriteRoleArn"`
EventRW string `json:"EventRW" xml:"EventRW"`
}
CreateTrailResponse is the response struct for api CreateTrail
func CreateCreateTrailResponse ¶
func CreateCreateTrailResponse() (response *CreateTrailResponse)
CreateCreateTrailResponse creates a response to parse from CreateTrail response
type DeleteTrailRequest ¶
type DeleteTrailRequest struct {
*requests.RpcRequest
Name string `position:"Query" name:"Name"`
}
DeleteTrailRequest is the request struct for api DeleteTrail
func CreateDeleteTrailRequest ¶
func CreateDeleteTrailRequest() (request *DeleteTrailRequest)
CreateDeleteTrailRequest creates a request to invoke DeleteTrail API
type DeleteTrailResponse ¶
type DeleteTrailResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
DeleteTrailResponse is the response struct for api DeleteTrail
func CreateDeleteTrailResponse ¶
func CreateDeleteTrailResponse() (response *DeleteTrailResponse)
CreateDeleteTrailResponse creates a response to parse from DeleteTrail response
type DescribeRegionsRequest ¶
type DescribeRegionsRequest struct {
*requests.RpcRequest
}
DescribeRegionsRequest is the request struct for api DescribeRegions
func CreateDescribeRegionsRequest ¶
func CreateDescribeRegionsRequest() (request *DescribeRegionsRequest)
CreateDescribeRegionsRequest creates a request to invoke DescribeRegions API
type DescribeRegionsResponse ¶
type DescribeRegionsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Regions Regions `json:"Regions" xml:"Regions"`
}
DescribeRegionsResponse is the response struct for api DescribeRegions
func CreateDescribeRegionsResponse ¶
func CreateDescribeRegionsResponse() (response *DescribeRegionsResponse)
CreateDescribeRegionsResponse creates a response to parse from DescribeRegions response
type DescribeTrailsRequest ¶
type DescribeTrailsRequest struct {
*requests.RpcRequest
NameList string `position:"Query" name:"NameList"`
IncludeShadowTrails requests.Boolean `position:"Query" name:"IncludeShadowTrails"`
}
DescribeTrailsRequest is the request struct for api DescribeTrails
func CreateDescribeTrailsRequest ¶
func CreateDescribeTrailsRequest() (request *DescribeTrailsRequest)
CreateDescribeTrailsRequest creates a request to invoke DescribeTrails API
type DescribeTrailsResponse ¶
type DescribeTrailsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TrailList []TrailListItem `json:"TrailList" xml:"TrailList"`
}
DescribeTrailsResponse is the response struct for api DescribeTrails
func CreateDescribeTrailsResponse ¶
func CreateDescribeTrailsResponse() (response *DescribeTrailsResponse)
CreateDescribeTrailsResponse creates a response to parse from DescribeTrails response
type Events ¶
type Events struct {
Events []map[string]interface{} `json:"Events" xml:"Events"`
}
Events is a nested struct in actiontrail response
type GetTrailStatusRequest ¶
type GetTrailStatusRequest struct {
*requests.RpcRequest
Name string `position:"Query" name:"Name"`
}
GetTrailStatusRequest is the request struct for api GetTrailStatus
func CreateGetTrailStatusRequest ¶
func CreateGetTrailStatusRequest() (request *GetTrailStatusRequest)
CreateGetTrailStatusRequest creates a request to invoke GetTrailStatus API
type GetTrailStatusResponse ¶
type GetTrailStatusResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
IsLogging bool `json:"IsLogging" xml:"IsLogging"`
LatestDeliveryError string `json:"LatestDeliveryError" xml:"LatestDeliveryError"`
LatestDeliveryTime string `json:"LatestDeliveryTime" xml:"LatestDeliveryTime"`
StartLoggingTime string `json:"StartLoggingTime" xml:"StartLoggingTime"`
StopLoggingTime string `json:"StopLoggingTime" xml:"StopLoggingTime"`
}
GetTrailStatusResponse is the response struct for api GetTrailStatus
func CreateGetTrailStatusResponse ¶
func CreateGetTrailStatusResponse() (response *GetTrailStatusResponse)
CreateGetTrailStatusResponse creates a response to parse from GetTrailStatus response
type LookupEventsRequest ¶
type LookupEventsRequest struct {
*requests.RpcRequest
Request string `position:"Query" name:"Request"`
EventAccessKeyId string `position:"Query" name:"EventAccessKeyId"`
EndTime string `position:"Query" name:"EndTime"`
EventRW string `position:"Query" name:"EventRW"`
StartTime string `position:"Query" name:"StartTime"`
ResourceType string `position:"Query" name:"ResourceType"`
EventName string `position:"Query" name:"EventName"`
NextToken string `position:"Query" name:"NextToken"`
MaxResults string `position:"Query" name:"MaxResults"`
EventType string `position:"Query" name:"EventType"`
ServiceName string `position:"Query" name:"ServiceName"`
ResourceName string `position:"Query" name:"ResourceName"`
Event string `position:"Query" name:"Event"`
User string `position:"Query" name:"User"`
}
LookupEventsRequest is the request struct for api LookupEvents
func CreateLookupEventsRequest ¶
func CreateLookupEventsRequest() (request *LookupEventsRequest)
CreateLookupEventsRequest creates a request to invoke LookupEvents API
type LookupEventsResponse ¶
type LookupEventsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
NextToken string `json:"NextToken" xml:"NextToken"`
StartTime string `json:"StartTime" xml:"StartTime"`
EndTime string `json:"EndTime" xml:"EndTime"`
Events []string `json:"Events" xml:"Events"`
}
LookupEventsResponse is the response struct for api LookupEvents
func CreateLookupEventsResponse ¶
func CreateLookupEventsResponse() (response *LookupEventsResponse)
CreateLookupEventsResponse creates a response to parse from LookupEvents response
type Region ¶
type Region struct {
RegionItem []RegionItem `json:"RegionItem" xml:"RegionItem"`
}
Region is a nested struct in actiontrail response
type RegionItem ¶
type RegionItem struct {
RegionId string `json:"RegionId" xml:"RegionId"`
}
RegionItem is a nested struct in actiontrail response
type Regions ¶
type Regions struct {
Region []RegionItem `json:"Region" xml:"Region"`
}
Regions is a nested struct in actiontrail response
type StartLoggingRequest ¶
type StartLoggingRequest struct {
*requests.RpcRequest
Name string `position:"Query" name:"Name"`
}
StartLoggingRequest is the request struct for api StartLogging
func CreateStartLoggingRequest ¶
func CreateStartLoggingRequest() (request *StartLoggingRequest)
CreateStartLoggingRequest creates a request to invoke StartLogging API
type StartLoggingResponse ¶
type StartLoggingResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Param string `json:"Param" xml:"Param"`
Result string `json:"Result" xml:"Result"`
}
StartLoggingResponse is the response struct for api StartLogging
func CreateStartLoggingResponse ¶
func CreateStartLoggingResponse() (response *StartLoggingResponse)
CreateStartLoggingResponse creates a response to parse from StartLogging response
type StopLoggingRequest ¶
type StopLoggingRequest struct {
*requests.RpcRequest
Name string `position:"Query" name:"Name"`
}
StopLoggingRequest is the request struct for api StopLogging
func CreateStopLoggingRequest ¶
func CreateStopLoggingRequest() (request *StopLoggingRequest)
CreateStopLoggingRequest creates a request to invoke StopLogging API
type StopLoggingResponse ¶
type StopLoggingResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Param string `json:"Param" xml:"Param"`
Result string `json:"Result" xml:"Result"`
}
StopLoggingResponse is the response struct for api StopLogging
func CreateStopLoggingResponse ¶
func CreateStopLoggingResponse() (response *StopLoggingResponse)
CreateStopLoggingResponse creates a response to parse from StopLogging response
type TrailList ¶
type TrailList struct {
TrailListItem []TrailListItem `json:"TrailListItem" xml:"TrailListItem"`
}
TrailList is a nested struct in actiontrail response
type TrailListItem ¶
type TrailListItem struct {
Name string `json:"Name" xml:"Name"`
HomeRegion string `json:"HomeRegion" xml:"HomeRegion"`
RoleName string `json:"RoleName" xml:"RoleName"`
Status string `json:"Status" xml:"Status"`
IncludeGlobalServiceEvent string `json:"IncludeGlobalServiceEvent" xml:"IncludeGlobalServiceEvent"`
OssBucketName string `json:"OssBucketName" xml:"OssBucketName"`
OssKeyPrefix string `json:"OssKeyPrefix" xml:"OssKeyPrefix"`
Region string `json:"Region" xml:"Region"`
EventRW string `json:"EventRW" xml:"EventRW"`
Type string `json:"Type" xml:"Type"`
SlsWriteRoleArn string `json:"SlsWriteRoleArn" xml:"SlsWriteRoleArn"`
SlsProjectArn string `json:"SlsProjectArn" xml:"SlsProjectArn"`
}
TrailListItem is a nested struct in actiontrail response
type UpdateTrailRequest ¶
type UpdateTrailRequest struct {
*requests.RpcRequest
SlsProjectArn string `position:"Query" name:"SlsProjectArn"`
SlsWriteRoleArn string `position:"Query" name:"SlsWriteRoleArn"`
RoleName string `position:"Query" name:"RoleName"`
Name string `position:"Query" name:"Name"`
OssBucketName string `position:"Query" name:"OssBucketName"`
OssKeyPrefix string `position:"Query" name:"OssKeyPrefix"`
EventRW string `position:"Query" name:"EventRW"`
}
UpdateTrailRequest is the request struct for api UpdateTrail
func CreateUpdateTrailRequest ¶
func CreateUpdateTrailRequest() (request *UpdateTrailRequest)
CreateUpdateTrailRequest creates a request to invoke UpdateTrail API
type UpdateTrailResponse ¶
type UpdateTrailResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Param string `json:"Param" xml:"Param"`
Result string `json:"Result" xml:"Result"`
Name string `json:"Name" xml:"Name"`
HomeRegion string `json:"HomeRegion" xml:"HomeRegion"`
OssBucketName string `json:"OssBucketName" xml:"OssBucketName"`
OssKeyPrefix string `json:"OssKeyPrefix" xml:"OssKeyPrefix"`
RoleName string `json:"RoleName" xml:"RoleName"`
SlsProjectArn string `json:"SlsProjectArn" xml:"SlsProjectArn"`
SlsWriteRoleArn string `json:"SlsWriteRoleArn" xml:"SlsWriteRoleArn"`
EventRW string `json:"EventRW" xml:"EventRW"`
}
UpdateTrailResponse is the response struct for api UpdateTrail
func CreateUpdateTrailResponse ¶
func CreateUpdateTrailResponse() (response *UpdateTrailResponse)
CreateUpdateTrailResponse creates a response to parse from UpdateTrail response