Documentation
¶
Index ¶
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) QueryTokenForMnsQueue(request *QueryTokenForMnsQueueRequest) (response *QueryTokenForMnsQueueResponse, err error)
- func (client *Client) QueryTokenForMnsQueueWithCallback(request *QueryTokenForMnsQueueRequest, ...) <-chan int
- func (client *Client) QueryTokenForMnsQueueWithChan(request *QueryTokenForMnsQueueRequest) (<-chan *QueryTokenForMnsQueueResponse, <-chan error)
- type MessageTokenDTO
- type QueryTokenForMnsQueueRequest
- type QueryTokenForMnsQueueResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://help.aliyun.com/document_detail/66217.html
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://help.aliyun.com/document_detail/66223.html
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://help.aliyun.com/document_detail/66222.html
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair attention: rsa key pair auth is only Japan regions available
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://help.aliyun.com/document_detail/66222.html
func (*Client) QueryTokenForMnsQueue ¶
func (client *Client) QueryTokenForMnsQueue(request *QueryTokenForMnsQueueRequest) (response *QueryTokenForMnsQueueResponse, err error)
QueryTokenForMnsQueue invokes the dybaseapi.QueryTokenForMnsQueue API synchronously api document: https://help.aliyun.com/api/dybaseapi/querytokenformnsqueue.html
func (*Client) QueryTokenForMnsQueueWithCallback ¶
func (client *Client) QueryTokenForMnsQueueWithCallback(request *QueryTokenForMnsQueueRequest, callback func(response *QueryTokenForMnsQueueResponse, err error)) <-chan int
QueryTokenForMnsQueueWithCallback invokes the dybaseapi.QueryTokenForMnsQueue API asynchronously api document: https://help.aliyun.com/api/dybaseapi/querytokenformnsqueue.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) QueryTokenForMnsQueueWithChan ¶
func (client *Client) QueryTokenForMnsQueueWithChan(request *QueryTokenForMnsQueueRequest) (<-chan *QueryTokenForMnsQueueResponse, <-chan error)
QueryTokenForMnsQueueWithChan invokes the dybaseapi.QueryTokenForMnsQueue API asynchronously api document: https://help.aliyun.com/api/dybaseapi/querytokenformnsqueue.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type MessageTokenDTO ¶
type MessageTokenDTO struct {
AccessKeyId string `json:"AccessKeyId" xml:"AccessKeyId"`
AccessKeySecret string `json:"AccessKeySecret" xml:"AccessKeySecret"`
SecurityToken string `json:"SecurityToken" xml:"SecurityToken"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
ExpireTime string `json:"ExpireTime" xml:"ExpireTime"`
}
MessageTokenDTO is a nested struct in dybaseapi response
type QueryTokenForMnsQueueRequest ¶
type QueryTokenForMnsQueueRequest struct {
*requests.RpcRequest
QueueName string `position:"Query" name:"QueueName"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
MessageType string `position:"Query" name:"MessageType"`
OwnerId requests.Integer `position:"Query" name:"OwnerId"`
}
QueryTokenForMnsQueueRequest is the request struct for api QueryTokenForMnsQueue
func CreateQueryTokenForMnsQueueRequest ¶
func CreateQueryTokenForMnsQueueRequest() (request *QueryTokenForMnsQueueRequest)
CreateQueryTokenForMnsQueueRequest creates a request to invoke QueryTokenForMnsQueue API
type QueryTokenForMnsQueueResponse ¶
type QueryTokenForMnsQueueResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
MessageTokenDTO MessageTokenDTO `json:"MessageTokenDTO" xml:"MessageTokenDTO"`
}
QueryTokenForMnsQueueResponse is the response struct for api QueryTokenForMnsQueue
func CreateQueryTokenForMnsQueueResponse ¶
func CreateQueryTokenForMnsQueueResponse() (response *QueryTokenForMnsQueueResponse)
CreateQueryTokenForMnsQueueResponse creates a response to parse from QueryTokenForMnsQueue response