Documentation
¶
Index ¶
- type AddZoneRecordRequest
- type AddZoneRecordResponse
- type AddZoneRequest
- type AddZoneResponse
- type BindVpcs
- type BindZoneVpcRequest
- type BindZoneVpcResponse
- type BindZoneVpcVpcs
- type ChangeLog
- type ChangeLogs
- type CheckZoneNameRequest
- type CheckZoneNameResponse
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) AddZone(request *AddZoneRequest) (response *AddZoneResponse, err error)
- func (client *Client) AddZoneRecord(request *AddZoneRecordRequest) (response *AddZoneRecordResponse, err error)
- func (client *Client) AddZoneRecordWithCallback(request *AddZoneRecordRequest, ...) <-chan int
- func (client *Client) AddZoneRecordWithChan(request *AddZoneRecordRequest) (<-chan *AddZoneRecordResponse, <-chan error)
- func (client *Client) AddZoneWithCallback(request *AddZoneRequest, callback func(response *AddZoneResponse, err error)) <-chan int
- func (client *Client) AddZoneWithChan(request *AddZoneRequest) (<-chan *AddZoneResponse, <-chan error)
- func (client *Client) BindZoneVpc(request *BindZoneVpcRequest) (response *BindZoneVpcResponse, err error)
- func (client *Client) BindZoneVpcWithCallback(request *BindZoneVpcRequest, ...) <-chan int
- func (client *Client) BindZoneVpcWithChan(request *BindZoneVpcRequest) (<-chan *BindZoneVpcResponse, <-chan error)
- func (client *Client) CheckZoneName(request *CheckZoneNameRequest) (response *CheckZoneNameResponse, err error)
- func (client *Client) CheckZoneNameWithCallback(request *CheckZoneNameRequest, ...) <-chan int
- func (client *Client) CheckZoneNameWithChan(request *CheckZoneNameRequest) (<-chan *CheckZoneNameResponse, <-chan error)
- func (client *Client) DeleteZone(request *DeleteZoneRequest) (response *DeleteZoneResponse, err error)
- func (client *Client) DeleteZoneRecord(request *DeleteZoneRecordRequest) (response *DeleteZoneRecordResponse, err error)
- func (client *Client) DeleteZoneRecordWithCallback(request *DeleteZoneRecordRequest, ...) <-chan int
- func (client *Client) DeleteZoneRecordWithChan(request *DeleteZoneRecordRequest) (<-chan *DeleteZoneRecordResponse, <-chan error)
- func (client *Client) DeleteZoneWithCallback(request *DeleteZoneRequest, ...) <-chan int
- func (client *Client) DeleteZoneWithChan(request *DeleteZoneRequest) (<-chan *DeleteZoneResponse, <-chan error)
- func (client *Client) DescribeChangeLogs(request *DescribeChangeLogsRequest) (response *DescribeChangeLogsResponse, err error)
- func (client *Client) DescribeChangeLogsWithCallback(request *DescribeChangeLogsRequest, ...) <-chan int
- func (client *Client) DescribeChangeLogsWithChan(request *DescribeChangeLogsRequest) (<-chan *DescribeChangeLogsResponse, <-chan error)
- func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
- func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, ...) <-chan int
- func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
- func (client *Client) DescribeRequestGraph(request *DescribeRequestGraphRequest) (response *DescribeRequestGraphResponse, err error)
- func (client *Client) DescribeRequestGraphWithCallback(request *DescribeRequestGraphRequest, ...) <-chan int
- func (client *Client) DescribeRequestGraphWithChan(request *DescribeRequestGraphRequest) (<-chan *DescribeRequestGraphResponse, <-chan error)
- func (client *Client) DescribeStatisticSummary(request *DescribeStatisticSummaryRequest) (response *DescribeStatisticSummaryResponse, err error)
- func (client *Client) DescribeStatisticSummaryWithCallback(request *DescribeStatisticSummaryRequest, ...) <-chan int
- func (client *Client) DescribeStatisticSummaryWithChan(request *DescribeStatisticSummaryRequest) (<-chan *DescribeStatisticSummaryResponse, <-chan error)
- func (client *Client) DescribeUserServiceStatus(request *DescribeUserServiceStatusRequest) (response *DescribeUserServiceStatusResponse, err error)
- func (client *Client) DescribeUserServiceStatusWithCallback(request *DescribeUserServiceStatusRequest, ...) <-chan int
- func (client *Client) DescribeUserServiceStatusWithChan(request *DescribeUserServiceStatusRequest) (<-chan *DescribeUserServiceStatusResponse, <-chan error)
- func (client *Client) DescribeZoneInfo(request *DescribeZoneInfoRequest) (response *DescribeZoneInfoResponse, err error)
- func (client *Client) DescribeZoneInfoWithCallback(request *DescribeZoneInfoRequest, ...) <-chan int
- func (client *Client) DescribeZoneInfoWithChan(request *DescribeZoneInfoRequest) (<-chan *DescribeZoneInfoResponse, <-chan error)
- func (client *Client) DescribeZoneRecords(request *DescribeZoneRecordsRequest) (response *DescribeZoneRecordsResponse, err error)
- func (client *Client) DescribeZoneRecordsWithCallback(request *DescribeZoneRecordsRequest, ...) <-chan int
- func (client *Client) DescribeZoneRecordsWithChan(request *DescribeZoneRecordsRequest) (<-chan *DescribeZoneRecordsResponse, <-chan error)
- func (client *Client) DescribeZoneVpcTree(request *DescribeZoneVpcTreeRequest) (response *DescribeZoneVpcTreeResponse, err error)
- func (client *Client) DescribeZoneVpcTreeWithCallback(request *DescribeZoneVpcTreeRequest, ...) <-chan int
- func (client *Client) DescribeZoneVpcTreeWithChan(request *DescribeZoneVpcTreeRequest) (<-chan *DescribeZoneVpcTreeResponse, <-chan error)
- func (client *Client) DescribeZones(request *DescribeZonesRequest) (response *DescribeZonesResponse, err error)
- func (client *Client) DescribeZonesWithCallback(request *DescribeZonesRequest, ...) <-chan int
- func (client *Client) DescribeZonesWithChan(request *DescribeZonesRequest) (<-chan *DescribeZonesResponse, <-chan error)
- func (client *Client) SetProxyPattern(request *SetProxyPatternRequest) (response *SetProxyPatternResponse, err error)
- func (client *Client) SetProxyPatternWithCallback(request *SetProxyPatternRequest, ...) <-chan int
- func (client *Client) SetProxyPatternWithChan(request *SetProxyPatternRequest) (<-chan *SetProxyPatternResponse, <-chan error)
- func (client *Client) SetZoneRecordStatus(request *SetZoneRecordStatusRequest) (response *SetZoneRecordStatusResponse, err error)
- func (client *Client) SetZoneRecordStatusWithCallback(request *SetZoneRecordStatusRequest, ...) <-chan int
- func (client *Client) SetZoneRecordStatusWithChan(request *SetZoneRecordStatusRequest) (<-chan *SetZoneRecordStatusResponse, <-chan error)
- func (client *Client) UpdateZoneRecord(request *UpdateZoneRecordRequest) (response *UpdateZoneRecordResponse, err error)
- func (client *Client) UpdateZoneRecordWithCallback(request *UpdateZoneRecordRequest, ...) <-chan int
- func (client *Client) UpdateZoneRecordWithChan(request *UpdateZoneRecordRequest) (<-chan *UpdateZoneRecordResponse, <-chan error)
- func (client *Client) UpdateZoneRemark(request *UpdateZoneRemarkRequest) (response *UpdateZoneRemarkResponse, err error)
- func (client *Client) UpdateZoneRemarkWithCallback(request *UpdateZoneRemarkRequest, ...) <-chan int
- func (client *Client) UpdateZoneRemarkWithChan(request *UpdateZoneRemarkRequest) (<-chan *UpdateZoneRemarkResponse, <-chan error)
- type DeleteZoneRecordRequest
- type DeleteZoneRecordResponse
- type DeleteZoneRequest
- type DeleteZoneResponse
- type DescribeChangeLogsRequest
- type DescribeChangeLogsResponse
- type DescribeRegionsRequest
- type DescribeRegionsResponse
- type DescribeRequestGraphRequest
- type DescribeRequestGraphResponse
- type DescribeStatisticSummaryRequest
- type DescribeStatisticSummaryResponse
- type DescribeUserServiceStatusRequest
- type DescribeUserServiceStatusResponse
- type DescribeZoneInfoRequest
- type DescribeZoneInfoResponse
- type DescribeZoneRecordsRequest
- type DescribeZoneRecordsResponse
- type DescribeZoneVpcTreeRequest
- type DescribeZoneVpcTreeResponse
- type DescribeZonesRequest
- type DescribeZonesResponse
- type Record
- type Records
- type Region
- type Regions
- type RequestDetails
- type SetProxyPatternRequest
- type SetProxyPatternResponse
- type SetZoneRecordStatusRequest
- type SetZoneRecordStatusResponse
- type UpdateZoneRecordRequest
- type UpdateZoneRecordResponse
- type UpdateZoneRemarkRequest
- type UpdateZoneRemarkResponse
- type Vpc
- type VpcRequestTop
- type VpcRequestTops
- type Vpcs
- type Zone
- type ZoneRequestTop
- type ZoneRequestTops
- type ZonesInDescribeZoneVpcTree
- type ZonesInDescribeZones
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddZoneRecordRequest ¶
type AddZoneRecordRequest struct {
*requests.RpcRequest
Rr string `position:"Query" name:"Rr"`
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
Type string `position:"Query" name:"Type"`
Priority requests.Integer `position:"Query" name:"Priority"`
Ttl requests.Integer `position:"Query" name:"Ttl"`
Value string `position:"Query" name:"Value"`
}
AddZoneRecordRequest is the request struct for api AddZoneRecord
func CreateAddZoneRecordRequest ¶
func CreateAddZoneRecordRequest() (request *AddZoneRecordRequest)
CreateAddZoneRecordRequest creates a request to invoke AddZoneRecord API
type AddZoneRecordResponse ¶
type AddZoneRecordResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Success bool `json:"Success" xml:"Success"`
RecordId int `json:"RecordId" xml:"RecordId"`
}
AddZoneRecordResponse is the response struct for api AddZoneRecord
func CreateAddZoneRecordResponse ¶
func CreateAddZoneRecordResponse() (response *AddZoneRecordResponse)
CreateAddZoneRecordResponse creates a response to parse from AddZoneRecord response
type AddZoneRequest ¶
type AddZoneRequest struct {
*requests.RpcRequest
ProxyPattern string `position:"Query" name:"ProxyPattern"`
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
ZoneName string `position:"Query" name:"ZoneName"`
}
AddZoneRequest is the request struct for api AddZone
func CreateAddZoneRequest ¶
func CreateAddZoneRequest() (request *AddZoneRequest)
CreateAddZoneRequest creates a request to invoke AddZone API
type AddZoneResponse ¶
type AddZoneResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Success bool `json:"Success" xml:"Success"`
ZoneId string `json:"ZoneId" xml:"ZoneId"`
ZoneName string `json:"ZoneName" xml:"ZoneName"`
}
AddZoneResponse is the response struct for api AddZone
func CreateAddZoneResponse ¶
func CreateAddZoneResponse() (response *AddZoneResponse)
CreateAddZoneResponse creates a response to parse from AddZone response
type BindVpcs ¶
type BindVpcs struct {
Vpc []Vpc `json:"Vpc" xml:"Vpc"`
}
BindVpcs is a nested struct in pvtz response
type BindZoneVpcRequest ¶
type BindZoneVpcRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
Vpcs *[]BindZoneVpcVpcs `position:"Query" name:"Vpcs" type:"Repeated"`
}
BindZoneVpcRequest is the request struct for api BindZoneVpc
func CreateBindZoneVpcRequest ¶
func CreateBindZoneVpcRequest() (request *BindZoneVpcRequest)
CreateBindZoneVpcRequest creates a request to invoke BindZoneVpc API
type BindZoneVpcResponse ¶
type BindZoneVpcResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
BindZoneVpcResponse is the response struct for api BindZoneVpc
func CreateBindZoneVpcResponse ¶
func CreateBindZoneVpcResponse() (response *BindZoneVpcResponse)
CreateBindZoneVpcResponse creates a response to parse from BindZoneVpc response
type BindZoneVpcVpcs ¶
BindZoneVpcVpcs is a repeated param struct in BindZoneVpcRequest
type ChangeLog ¶
type ChangeLog struct {
OperTime string `json:"OperTime" xml:"OperTime"`
OperAction string `json:"OperAction" xml:"OperAction"`
OperObject string `json:"OperObject" xml:"OperObject"`
EntityId string `json:"EntityId" xml:"EntityId"`
EntityName string `json:"EntityName" xml:"EntityName"`
OperIp string `json:"OperIp" xml:"OperIp"`
OperTimestamp int `json:"OperTimestamp" xml:"OperTimestamp"`
Id int `json:"Id" xml:"Id"`
Content string `json:"Content" xml:"Content"`
}
ChangeLog is a nested struct in pvtz response
type ChangeLogs ¶
type ChangeLogs struct {
ChangeLog []ChangeLog `json:"ChangeLog" xml:"ChangeLog"`
}
ChangeLogs is a nested struct in pvtz response
type CheckZoneNameRequest ¶
type CheckZoneNameRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
ZoneName string `position:"Query" name:"ZoneName"`
}
CheckZoneNameRequest is the request struct for api CheckZoneName
func CreateCheckZoneNameRequest ¶
func CreateCheckZoneNameRequest() (request *CheckZoneNameRequest)
CreateCheckZoneNameRequest creates a request to invoke CheckZoneName API
type CheckZoneNameResponse ¶
type CheckZoneNameResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Success bool `json:"Success" xml:"Success"`
Check bool `json:"Check" xml:"Check"`
}
CheckZoneNameResponse is the response struct for api CheckZoneName
func CreateCheckZoneNameResponse ¶
func CreateCheckZoneNameResponse() (response *CheckZoneNameResponse)
CreateCheckZoneNameResponse creates a response to parse from CheckZoneName response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://help.aliyun.com/document_detail/66217.html
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://help.aliyun.com/document_detail/66223.html
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://help.aliyun.com/document_detail/66222.html
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair attention: rsa key pair auth is only Japan regions available
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://help.aliyun.com/document_detail/66222.html
func (*Client) AddZone ¶
func (client *Client) AddZone(request *AddZoneRequest) (response *AddZoneResponse, err error)
AddZone invokes the pvtz.AddZone API synchronously api document: https://help.aliyun.com/api/pvtz/addzone.html
func (*Client) AddZoneRecord ¶
func (client *Client) AddZoneRecord(request *AddZoneRecordRequest) (response *AddZoneRecordResponse, err error)
AddZoneRecord invokes the pvtz.AddZoneRecord API synchronously api document: https://help.aliyun.com/api/pvtz/addzonerecord.html
func (*Client) AddZoneRecordWithCallback ¶
func (client *Client) AddZoneRecordWithCallback(request *AddZoneRecordRequest, callback func(response *AddZoneRecordResponse, err error)) <-chan int
AddZoneRecordWithCallback invokes the pvtz.AddZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/addzonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AddZoneRecordWithChan ¶
func (client *Client) AddZoneRecordWithChan(request *AddZoneRecordRequest) (<-chan *AddZoneRecordResponse, <-chan error)
AddZoneRecordWithChan invokes the pvtz.AddZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/addzonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AddZoneWithCallback ¶
func (client *Client) AddZoneWithCallback(request *AddZoneRequest, callback func(response *AddZoneResponse, err error)) <-chan int
AddZoneWithCallback invokes the pvtz.AddZone API asynchronously api document: https://help.aliyun.com/api/pvtz/addzone.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AddZoneWithChan ¶
func (client *Client) AddZoneWithChan(request *AddZoneRequest) (<-chan *AddZoneResponse, <-chan error)
AddZoneWithChan invokes the pvtz.AddZone API asynchronously api document: https://help.aliyun.com/api/pvtz/addzone.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) BindZoneVpc ¶
func (client *Client) BindZoneVpc(request *BindZoneVpcRequest) (response *BindZoneVpcResponse, err error)
BindZoneVpc invokes the pvtz.BindZoneVpc API synchronously api document: https://help.aliyun.com/api/pvtz/bindzonevpc.html
func (*Client) BindZoneVpcWithCallback ¶
func (client *Client) BindZoneVpcWithCallback(request *BindZoneVpcRequest, callback func(response *BindZoneVpcResponse, err error)) <-chan int
BindZoneVpcWithCallback invokes the pvtz.BindZoneVpc API asynchronously api document: https://help.aliyun.com/api/pvtz/bindzonevpc.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) BindZoneVpcWithChan ¶
func (client *Client) BindZoneVpcWithChan(request *BindZoneVpcRequest) (<-chan *BindZoneVpcResponse, <-chan error)
BindZoneVpcWithChan invokes the pvtz.BindZoneVpc API asynchronously api document: https://help.aliyun.com/api/pvtz/bindzonevpc.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CheckZoneName ¶
func (client *Client) CheckZoneName(request *CheckZoneNameRequest) (response *CheckZoneNameResponse, err error)
CheckZoneName invokes the pvtz.CheckZoneName API synchronously api document: https://help.aliyun.com/api/pvtz/checkzonename.html
func (*Client) CheckZoneNameWithCallback ¶
func (client *Client) CheckZoneNameWithCallback(request *CheckZoneNameRequest, callback func(response *CheckZoneNameResponse, err error)) <-chan int
CheckZoneNameWithCallback invokes the pvtz.CheckZoneName API asynchronously api document: https://help.aliyun.com/api/pvtz/checkzonename.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CheckZoneNameWithChan ¶
func (client *Client) CheckZoneNameWithChan(request *CheckZoneNameRequest) (<-chan *CheckZoneNameResponse, <-chan error)
CheckZoneNameWithChan invokes the pvtz.CheckZoneName API asynchronously api document: https://help.aliyun.com/api/pvtz/checkzonename.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteZone ¶
func (client *Client) DeleteZone(request *DeleteZoneRequest) (response *DeleteZoneResponse, err error)
DeleteZone invokes the pvtz.DeleteZone API synchronously api document: https://help.aliyun.com/api/pvtz/deletezone.html
func (*Client) DeleteZoneRecord ¶
func (client *Client) DeleteZoneRecord(request *DeleteZoneRecordRequest) (response *DeleteZoneRecordResponse, err error)
DeleteZoneRecord invokes the pvtz.DeleteZoneRecord API synchronously api document: https://help.aliyun.com/api/pvtz/deletezonerecord.html
func (*Client) DeleteZoneRecordWithCallback ¶
func (client *Client) DeleteZoneRecordWithCallback(request *DeleteZoneRecordRequest, callback func(response *DeleteZoneRecordResponse, err error)) <-chan int
DeleteZoneRecordWithCallback invokes the pvtz.DeleteZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/deletezonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteZoneRecordWithChan ¶
func (client *Client) DeleteZoneRecordWithChan(request *DeleteZoneRecordRequest) (<-chan *DeleteZoneRecordResponse, <-chan error)
DeleteZoneRecordWithChan invokes the pvtz.DeleteZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/deletezonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteZoneWithCallback ¶
func (client *Client) DeleteZoneWithCallback(request *DeleteZoneRequest, callback func(response *DeleteZoneResponse, err error)) <-chan int
DeleteZoneWithCallback invokes the pvtz.DeleteZone API asynchronously api document: https://help.aliyun.com/api/pvtz/deletezone.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteZoneWithChan ¶
func (client *Client) DeleteZoneWithChan(request *DeleteZoneRequest) (<-chan *DeleteZoneResponse, <-chan error)
DeleteZoneWithChan invokes the pvtz.DeleteZone API asynchronously api document: https://help.aliyun.com/api/pvtz/deletezone.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeChangeLogs ¶
func (client *Client) DescribeChangeLogs(request *DescribeChangeLogsRequest) (response *DescribeChangeLogsResponse, err error)
DescribeChangeLogs invokes the pvtz.DescribeChangeLogs API synchronously api document: https://help.aliyun.com/api/pvtz/describechangelogs.html
func (*Client) DescribeChangeLogsWithCallback ¶
func (client *Client) DescribeChangeLogsWithCallback(request *DescribeChangeLogsRequest, callback func(response *DescribeChangeLogsResponse, err error)) <-chan int
DescribeChangeLogsWithCallback invokes the pvtz.DescribeChangeLogs API asynchronously api document: https://help.aliyun.com/api/pvtz/describechangelogs.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeChangeLogsWithChan ¶
func (client *Client) DescribeChangeLogsWithChan(request *DescribeChangeLogsRequest) (<-chan *DescribeChangeLogsResponse, <-chan error)
DescribeChangeLogsWithChan invokes the pvtz.DescribeChangeLogs API asynchronously api document: https://help.aliyun.com/api/pvtz/describechangelogs.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRegions ¶
func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
DescribeRegions invokes the pvtz.DescribeRegions API synchronously api document: https://help.aliyun.com/api/pvtz/describeregions.html
func (*Client) DescribeRegionsWithCallback ¶
func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, callback func(response *DescribeRegionsResponse, err error)) <-chan int
DescribeRegionsWithCallback invokes the pvtz.DescribeRegions API asynchronously api document: https://help.aliyun.com/api/pvtz/describeregions.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRegionsWithChan ¶
func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
DescribeRegionsWithChan invokes the pvtz.DescribeRegions API asynchronously api document: https://help.aliyun.com/api/pvtz/describeregions.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRequestGraph ¶
func (client *Client) DescribeRequestGraph(request *DescribeRequestGraphRequest) (response *DescribeRequestGraphResponse, err error)
DescribeRequestGraph invokes the pvtz.DescribeRequestGraph API synchronously api document: https://help.aliyun.com/api/pvtz/describerequestgraph.html
func (*Client) DescribeRequestGraphWithCallback ¶
func (client *Client) DescribeRequestGraphWithCallback(request *DescribeRequestGraphRequest, callback func(response *DescribeRequestGraphResponse, err error)) <-chan int
DescribeRequestGraphWithCallback invokes the pvtz.DescribeRequestGraph API asynchronously api document: https://help.aliyun.com/api/pvtz/describerequestgraph.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeRequestGraphWithChan ¶
func (client *Client) DescribeRequestGraphWithChan(request *DescribeRequestGraphRequest) (<-chan *DescribeRequestGraphResponse, <-chan error)
DescribeRequestGraphWithChan invokes the pvtz.DescribeRequestGraph API asynchronously api document: https://help.aliyun.com/api/pvtz/describerequestgraph.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeStatisticSummary ¶
func (client *Client) DescribeStatisticSummary(request *DescribeStatisticSummaryRequest) (response *DescribeStatisticSummaryResponse, err error)
DescribeStatisticSummary invokes the pvtz.DescribeStatisticSummary API synchronously api document: https://help.aliyun.com/api/pvtz/describestatisticsummary.html
func (*Client) DescribeStatisticSummaryWithCallback ¶
func (client *Client) DescribeStatisticSummaryWithCallback(request *DescribeStatisticSummaryRequest, callback func(response *DescribeStatisticSummaryResponse, err error)) <-chan int
DescribeStatisticSummaryWithCallback invokes the pvtz.DescribeStatisticSummary API asynchronously api document: https://help.aliyun.com/api/pvtz/describestatisticsummary.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeStatisticSummaryWithChan ¶
func (client *Client) DescribeStatisticSummaryWithChan(request *DescribeStatisticSummaryRequest) (<-chan *DescribeStatisticSummaryResponse, <-chan error)
DescribeStatisticSummaryWithChan invokes the pvtz.DescribeStatisticSummary API asynchronously api document: https://help.aliyun.com/api/pvtz/describestatisticsummary.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeUserServiceStatus ¶
func (client *Client) DescribeUserServiceStatus(request *DescribeUserServiceStatusRequest) (response *DescribeUserServiceStatusResponse, err error)
DescribeUserServiceStatus invokes the pvtz.DescribeUserServiceStatus API synchronously api document: https://help.aliyun.com/api/pvtz/describeuserservicestatus.html
func (*Client) DescribeUserServiceStatusWithCallback ¶
func (client *Client) DescribeUserServiceStatusWithCallback(request *DescribeUserServiceStatusRequest, callback func(response *DescribeUserServiceStatusResponse, err error)) <-chan int
DescribeUserServiceStatusWithCallback invokes the pvtz.DescribeUserServiceStatus API asynchronously api document: https://help.aliyun.com/api/pvtz/describeuserservicestatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeUserServiceStatusWithChan ¶
func (client *Client) DescribeUserServiceStatusWithChan(request *DescribeUserServiceStatusRequest) (<-chan *DescribeUserServiceStatusResponse, <-chan error)
DescribeUserServiceStatusWithChan invokes the pvtz.DescribeUserServiceStatus API asynchronously api document: https://help.aliyun.com/api/pvtz/describeuserservicestatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneInfo ¶
func (client *Client) DescribeZoneInfo(request *DescribeZoneInfoRequest) (response *DescribeZoneInfoResponse, err error)
DescribeZoneInfo invokes the pvtz.DescribeZoneInfo API synchronously api document: https://help.aliyun.com/api/pvtz/describezoneinfo.html
func (*Client) DescribeZoneInfoWithCallback ¶
func (client *Client) DescribeZoneInfoWithCallback(request *DescribeZoneInfoRequest, callback func(response *DescribeZoneInfoResponse, err error)) <-chan int
DescribeZoneInfoWithCallback invokes the pvtz.DescribeZoneInfo API asynchronously api document: https://help.aliyun.com/api/pvtz/describezoneinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneInfoWithChan ¶
func (client *Client) DescribeZoneInfoWithChan(request *DescribeZoneInfoRequest) (<-chan *DescribeZoneInfoResponse, <-chan error)
DescribeZoneInfoWithChan invokes the pvtz.DescribeZoneInfo API asynchronously api document: https://help.aliyun.com/api/pvtz/describezoneinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneRecords ¶
func (client *Client) DescribeZoneRecords(request *DescribeZoneRecordsRequest) (response *DescribeZoneRecordsResponse, err error)
DescribeZoneRecords invokes the pvtz.DescribeZoneRecords API synchronously api document: https://help.aliyun.com/api/pvtz/describezonerecords.html
func (*Client) DescribeZoneRecordsWithCallback ¶
func (client *Client) DescribeZoneRecordsWithCallback(request *DescribeZoneRecordsRequest, callback func(response *DescribeZoneRecordsResponse, err error)) <-chan int
DescribeZoneRecordsWithCallback invokes the pvtz.DescribeZoneRecords API asynchronously api document: https://help.aliyun.com/api/pvtz/describezonerecords.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneRecordsWithChan ¶
func (client *Client) DescribeZoneRecordsWithChan(request *DescribeZoneRecordsRequest) (<-chan *DescribeZoneRecordsResponse, <-chan error)
DescribeZoneRecordsWithChan invokes the pvtz.DescribeZoneRecords API asynchronously api document: https://help.aliyun.com/api/pvtz/describezonerecords.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneVpcTree ¶
func (client *Client) DescribeZoneVpcTree(request *DescribeZoneVpcTreeRequest) (response *DescribeZoneVpcTreeResponse, err error)
DescribeZoneVpcTree invokes the pvtz.DescribeZoneVpcTree API synchronously api document: https://help.aliyun.com/api/pvtz/describezonevpctree.html
func (*Client) DescribeZoneVpcTreeWithCallback ¶
func (client *Client) DescribeZoneVpcTreeWithCallback(request *DescribeZoneVpcTreeRequest, callback func(response *DescribeZoneVpcTreeResponse, err error)) <-chan int
DescribeZoneVpcTreeWithCallback invokes the pvtz.DescribeZoneVpcTree API asynchronously api document: https://help.aliyun.com/api/pvtz/describezonevpctree.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZoneVpcTreeWithChan ¶
func (client *Client) DescribeZoneVpcTreeWithChan(request *DescribeZoneVpcTreeRequest) (<-chan *DescribeZoneVpcTreeResponse, <-chan error)
DescribeZoneVpcTreeWithChan invokes the pvtz.DescribeZoneVpcTree API asynchronously api document: https://help.aliyun.com/api/pvtz/describezonevpctree.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZones ¶
func (client *Client) DescribeZones(request *DescribeZonesRequest) (response *DescribeZonesResponse, err error)
DescribeZones invokes the pvtz.DescribeZones API synchronously api document: https://help.aliyun.com/api/pvtz/describezones.html
func (*Client) DescribeZonesWithCallback ¶
func (client *Client) DescribeZonesWithCallback(request *DescribeZonesRequest, callback func(response *DescribeZonesResponse, err error)) <-chan int
DescribeZonesWithCallback invokes the pvtz.DescribeZones API asynchronously api document: https://help.aliyun.com/api/pvtz/describezones.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeZonesWithChan ¶
func (client *Client) DescribeZonesWithChan(request *DescribeZonesRequest) (<-chan *DescribeZonesResponse, <-chan error)
DescribeZonesWithChan invokes the pvtz.DescribeZones API asynchronously api document: https://help.aliyun.com/api/pvtz/describezones.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetProxyPattern ¶
func (client *Client) SetProxyPattern(request *SetProxyPatternRequest) (response *SetProxyPatternResponse, err error)
SetProxyPattern invokes the pvtz.SetProxyPattern API synchronously api document: https://help.aliyun.com/api/pvtz/setproxypattern.html
func (*Client) SetProxyPatternWithCallback ¶
func (client *Client) SetProxyPatternWithCallback(request *SetProxyPatternRequest, callback func(response *SetProxyPatternResponse, err error)) <-chan int
SetProxyPatternWithCallback invokes the pvtz.SetProxyPattern API asynchronously api document: https://help.aliyun.com/api/pvtz/setproxypattern.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetProxyPatternWithChan ¶
func (client *Client) SetProxyPatternWithChan(request *SetProxyPatternRequest) (<-chan *SetProxyPatternResponse, <-chan error)
SetProxyPatternWithChan invokes the pvtz.SetProxyPattern API asynchronously api document: https://help.aliyun.com/api/pvtz/setproxypattern.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetZoneRecordStatus ¶
func (client *Client) SetZoneRecordStatus(request *SetZoneRecordStatusRequest) (response *SetZoneRecordStatusResponse, err error)
SetZoneRecordStatus invokes the pvtz.SetZoneRecordStatus API synchronously api document: https://help.aliyun.com/api/pvtz/setzonerecordstatus.html
func (*Client) SetZoneRecordStatusWithCallback ¶
func (client *Client) SetZoneRecordStatusWithCallback(request *SetZoneRecordStatusRequest, callback func(response *SetZoneRecordStatusResponse, err error)) <-chan int
SetZoneRecordStatusWithCallback invokes the pvtz.SetZoneRecordStatus API asynchronously api document: https://help.aliyun.com/api/pvtz/setzonerecordstatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetZoneRecordStatusWithChan ¶
func (client *Client) SetZoneRecordStatusWithChan(request *SetZoneRecordStatusRequest) (<-chan *SetZoneRecordStatusResponse, <-chan error)
SetZoneRecordStatusWithChan invokes the pvtz.SetZoneRecordStatus API asynchronously api document: https://help.aliyun.com/api/pvtz/setzonerecordstatus.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateZoneRecord ¶
func (client *Client) UpdateZoneRecord(request *UpdateZoneRecordRequest) (response *UpdateZoneRecordResponse, err error)
UpdateZoneRecord invokes the pvtz.UpdateZoneRecord API synchronously api document: https://help.aliyun.com/api/pvtz/updatezonerecord.html
func (*Client) UpdateZoneRecordWithCallback ¶
func (client *Client) UpdateZoneRecordWithCallback(request *UpdateZoneRecordRequest, callback func(response *UpdateZoneRecordResponse, err error)) <-chan int
UpdateZoneRecordWithCallback invokes the pvtz.UpdateZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/updatezonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateZoneRecordWithChan ¶
func (client *Client) UpdateZoneRecordWithChan(request *UpdateZoneRecordRequest) (<-chan *UpdateZoneRecordResponse, <-chan error)
UpdateZoneRecordWithChan invokes the pvtz.UpdateZoneRecord API asynchronously api document: https://help.aliyun.com/api/pvtz/updatezonerecord.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateZoneRemark ¶
func (client *Client) UpdateZoneRemark(request *UpdateZoneRemarkRequest) (response *UpdateZoneRemarkResponse, err error)
UpdateZoneRemark invokes the pvtz.UpdateZoneRemark API synchronously api document: https://help.aliyun.com/api/pvtz/updatezoneremark.html
func (*Client) UpdateZoneRemarkWithCallback ¶
func (client *Client) UpdateZoneRemarkWithCallback(request *UpdateZoneRemarkRequest, callback func(response *UpdateZoneRemarkResponse, err error)) <-chan int
UpdateZoneRemarkWithCallback invokes the pvtz.UpdateZoneRemark API asynchronously api document: https://help.aliyun.com/api/pvtz/updatezoneremark.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateZoneRemarkWithChan ¶
func (client *Client) UpdateZoneRemarkWithChan(request *UpdateZoneRemarkRequest) (<-chan *UpdateZoneRemarkResponse, <-chan error)
UpdateZoneRemarkWithChan invokes the pvtz.UpdateZoneRemark API asynchronously api document: https://help.aliyun.com/api/pvtz/updatezoneremark.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type DeleteZoneRecordRequest ¶
type DeleteZoneRecordRequest struct {
*requests.RpcRequest
RecordId requests.Integer `position:"Query" name:"RecordId"`
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
}
DeleteZoneRecordRequest is the request struct for api DeleteZoneRecord
func CreateDeleteZoneRecordRequest ¶
func CreateDeleteZoneRecordRequest() (request *DeleteZoneRecordRequest)
CreateDeleteZoneRecordRequest creates a request to invoke DeleteZoneRecord API
type DeleteZoneRecordResponse ¶
type DeleteZoneRecordResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
RecordId int `json:"RecordId" xml:"RecordId"`
}
DeleteZoneRecordResponse is the response struct for api DeleteZoneRecord
func CreateDeleteZoneRecordResponse ¶
func CreateDeleteZoneRecordResponse() (response *DeleteZoneRecordResponse)
CreateDeleteZoneRecordResponse creates a response to parse from DeleteZoneRecord response
type DeleteZoneRequest ¶
type DeleteZoneRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
}
DeleteZoneRequest is the request struct for api DeleteZone
func CreateDeleteZoneRequest ¶
func CreateDeleteZoneRequest() (request *DeleteZoneRequest)
CreateDeleteZoneRequest creates a request to invoke DeleteZone API
type DeleteZoneResponse ¶
type DeleteZoneResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ZoneId string `json:"ZoneId" xml:"ZoneId"`
}
DeleteZoneResponse is the response struct for api DeleteZone
func CreateDeleteZoneResponse ¶
func CreateDeleteZoneResponse() (response *DeleteZoneResponse)
CreateDeleteZoneResponse creates a response to parse from DeleteZone response
type DescribeChangeLogsRequest ¶
type DescribeChangeLogsRequest struct {
*requests.RpcRequest
EntityType string `position:"Query" name:"EntityType"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Keyword string `position:"Query" name:"Keyword"`
Lang string `position:"Query" name:"Lang"`
StartTimestamp requests.Integer `position:"Query" name:"StartTimestamp"`
PageNumber requests.Integer `position:"Query" name:"PageNumber"`
EndTimestamp requests.Integer `position:"Query" name:"EndTimestamp"`
}
DescribeChangeLogsRequest is the request struct for api DescribeChangeLogs
func CreateDescribeChangeLogsRequest ¶
func CreateDescribeChangeLogsRequest() (request *DescribeChangeLogsRequest)
CreateDescribeChangeLogsRequest creates a request to invoke DescribeChangeLogs API
type DescribeChangeLogsResponse ¶
type DescribeChangeLogsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalItems int `json:"TotalItems" xml:"TotalItems"`
TotalPages int `json:"TotalPages" xml:"TotalPages"`
PageSize int `json:"PageSize" xml:"PageSize"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
ChangeLogs ChangeLogs `json:"ChangeLogs" xml:"ChangeLogs"`
}
DescribeChangeLogsResponse is the response struct for api DescribeChangeLogs
func CreateDescribeChangeLogsResponse ¶
func CreateDescribeChangeLogsResponse() (response *DescribeChangeLogsResponse)
CreateDescribeChangeLogsResponse creates a response to parse from DescribeChangeLogs response
type DescribeRegionsRequest ¶
type DescribeRegionsRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
AcceptLanguage string `position:"Query" name:"AcceptLanguage"`
Lang string `position:"Query" name:"Lang"`
}
DescribeRegionsRequest is the request struct for api DescribeRegions
func CreateDescribeRegionsRequest ¶
func CreateDescribeRegionsRequest() (request *DescribeRegionsRequest)
CreateDescribeRegionsRequest creates a request to invoke DescribeRegions API
type DescribeRegionsResponse ¶
type DescribeRegionsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Regions Regions `json:"Regions" xml:"Regions"`
}
DescribeRegionsResponse is the response struct for api DescribeRegions
func CreateDescribeRegionsResponse ¶
func CreateDescribeRegionsResponse() (response *DescribeRegionsResponse)
CreateDescribeRegionsResponse creates a response to parse from DescribeRegions response
type DescribeRequestGraphRequest ¶
type DescribeRequestGraphRequest struct {
*requests.RpcRequest
VpcId string `position:"Query" name:"VpcId"`
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
StartTimestamp requests.Integer `position:"Query" name:"StartTimestamp"`
EndTimestamp requests.Integer `position:"Query" name:"EndTimestamp"`
}
DescribeRequestGraphRequest is the request struct for api DescribeRequestGraph
func CreateDescribeRequestGraphRequest ¶
func CreateDescribeRequestGraphRequest() (request *DescribeRequestGraphRequest)
CreateDescribeRequestGraphRequest creates a request to invoke DescribeRequestGraph API
type DescribeRequestGraphResponse ¶
type DescribeRequestGraphResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
RequestDetails RequestDetails `json:"RequestDetails" xml:"RequestDetails"`
}
DescribeRequestGraphResponse is the response struct for api DescribeRequestGraph
func CreateDescribeRequestGraphResponse ¶
func CreateDescribeRequestGraphResponse() (response *DescribeRequestGraphResponse)
CreateDescribeRequestGraphResponse creates a response to parse from DescribeRequestGraph response
type DescribeStatisticSummaryRequest ¶
type DescribeStatisticSummaryRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
}
DescribeStatisticSummaryRequest is the request struct for api DescribeStatisticSummary
func CreateDescribeStatisticSummaryRequest ¶
func CreateDescribeStatisticSummaryRequest() (request *DescribeStatisticSummaryRequest)
CreateDescribeStatisticSummaryRequest creates a request to invoke DescribeStatisticSummary API
type DescribeStatisticSummaryResponse ¶
type DescribeStatisticSummaryResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
ZoneRequestTops ZoneRequestTops `json:"ZoneRequestTops" xml:"ZoneRequestTops"`
VpcRequestTops VpcRequestTops `json:"VpcRequestTops" xml:"VpcRequestTops"`
}
DescribeStatisticSummaryResponse is the response struct for api DescribeStatisticSummary
func CreateDescribeStatisticSummaryResponse ¶
func CreateDescribeStatisticSummaryResponse() (response *DescribeStatisticSummaryResponse)
CreateDescribeStatisticSummaryResponse creates a response to parse from DescribeStatisticSummary response
type DescribeUserServiceStatusRequest ¶
type DescribeUserServiceStatusRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
}
DescribeUserServiceStatusRequest is the request struct for api DescribeUserServiceStatus
func CreateDescribeUserServiceStatusRequest ¶
func CreateDescribeUserServiceStatusRequest() (request *DescribeUserServiceStatusRequest)
CreateDescribeUserServiceStatusRequest creates a request to invoke DescribeUserServiceStatus API
type DescribeUserServiceStatusResponse ¶
type DescribeUserServiceStatusResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Status string `json:"Status" xml:"Status"`
}
DescribeUserServiceStatusResponse is the response struct for api DescribeUserServiceStatus
func CreateDescribeUserServiceStatusResponse ¶
func CreateDescribeUserServiceStatusResponse() (response *DescribeUserServiceStatusResponse)
CreateDescribeUserServiceStatusResponse creates a response to parse from DescribeUserServiceStatus response
type DescribeZoneInfoRequest ¶
type DescribeZoneInfoRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
}
DescribeZoneInfoRequest is the request struct for api DescribeZoneInfo
func CreateDescribeZoneInfoRequest ¶
func CreateDescribeZoneInfoRequest() (request *DescribeZoneInfoRequest)
CreateDescribeZoneInfoRequest creates a request to invoke DescribeZoneInfo API
type DescribeZoneInfoResponse ¶
type DescribeZoneInfoResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ZoneId string `json:"ZoneId" xml:"ZoneId"`
ZoneName string `json:"ZoneName" xml:"ZoneName"`
Remark string `json:"Remark" xml:"Remark"`
RecordCount int `json:"RecordCount" xml:"RecordCount"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
CreateTimestamp int `json:"CreateTimestamp" xml:"CreateTimestamp"`
UpdateTime string `json:"UpdateTime" xml:"UpdateTime"`
UpdateTimestamp int `json:"UpdateTimestamp" xml:"UpdateTimestamp"`
IsPtr bool `json:"IsPtr" xml:"IsPtr"`
ProxyPattern string `json:"ProxyPattern" xml:"ProxyPattern"`
BindVpcs BindVpcs `json:"BindVpcs" xml:"BindVpcs"`
}
DescribeZoneInfoResponse is the response struct for api DescribeZoneInfo
func CreateDescribeZoneInfoResponse ¶
func CreateDescribeZoneInfoResponse() (response *DescribeZoneInfoResponse)
CreateDescribeZoneInfoResponse creates a response to parse from DescribeZoneInfo response
type DescribeZoneRecordsRequest ¶
type DescribeZoneRecordsRequest struct {
*requests.RpcRequest
PageSize requests.Integer `position:"Query" name:"PageSize"`
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
SearchMode string `position:"Query" name:"SearchMode"`
Tag string `position:"Query" name:"Tag"`
Lang string `position:"Query" name:"Lang"`
Keyword string `position:"Query" name:"Keyword"`
PageNumber requests.Integer `position:"Query" name:"PageNumber"`
}
DescribeZoneRecordsRequest is the request struct for api DescribeZoneRecords
func CreateDescribeZoneRecordsRequest ¶
func CreateDescribeZoneRecordsRequest() (request *DescribeZoneRecordsRequest)
CreateDescribeZoneRecordsRequest creates a request to invoke DescribeZoneRecords API
type DescribeZoneRecordsResponse ¶
type DescribeZoneRecordsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalItems int `json:"TotalItems" xml:"TotalItems"`
TotalPages int `json:"TotalPages" xml:"TotalPages"`
PageSize int `json:"PageSize" xml:"PageSize"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
Records Records `json:"Records" xml:"Records"`
}
DescribeZoneRecordsResponse is the response struct for api DescribeZoneRecords
func CreateDescribeZoneRecordsResponse ¶
func CreateDescribeZoneRecordsResponse() (response *DescribeZoneRecordsResponse)
CreateDescribeZoneRecordsResponse creates a response to parse from DescribeZoneRecords response
type DescribeZoneVpcTreeRequest ¶
type DescribeZoneVpcTreeRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
}
DescribeZoneVpcTreeRequest is the request struct for api DescribeZoneVpcTree
func CreateDescribeZoneVpcTreeRequest ¶
func CreateDescribeZoneVpcTreeRequest() (request *DescribeZoneVpcTreeRequest)
CreateDescribeZoneVpcTreeRequest creates a request to invoke DescribeZoneVpcTree API
type DescribeZoneVpcTreeResponse ¶
type DescribeZoneVpcTreeResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Zones ZonesInDescribeZoneVpcTree `json:"Zones" xml:"Zones"`
}
DescribeZoneVpcTreeResponse is the response struct for api DescribeZoneVpcTree
func CreateDescribeZoneVpcTreeResponse ¶
func CreateDescribeZoneVpcTreeResponse() (response *DescribeZoneVpcTreeResponse)
CreateDescribeZoneVpcTreeResponse creates a response to parse from DescribeZoneVpcTree response
type DescribeZonesRequest ¶
type DescribeZonesRequest struct {
*requests.RpcRequest
QueryVpcId string `position:"Query" name:"QueryVpcId"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
UserClientIp string `position:"Query" name:"UserClientIp"`
SearchMode string `position:"Query" name:"SearchMode"`
Lang string `position:"Query" name:"Lang"`
Keyword string `position:"Query" name:"Keyword"`
PageNumber requests.Integer `position:"Query" name:"PageNumber"`
QueryRegionId string `position:"Query" name:"QueryRegionId"`
}
DescribeZonesRequest is the request struct for api DescribeZones
func CreateDescribeZonesRequest ¶
func CreateDescribeZonesRequest() (request *DescribeZonesRequest)
CreateDescribeZonesRequest creates a request to invoke DescribeZones API
type DescribeZonesResponse ¶
type DescribeZonesResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalItems int `json:"TotalItems" xml:"TotalItems"`
TotalPages int `json:"TotalPages" xml:"TotalPages"`
PageSize int `json:"PageSize" xml:"PageSize"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
Zones ZonesInDescribeZones `json:"Zones" xml:"Zones"`
}
DescribeZonesResponse is the response struct for api DescribeZones
func CreateDescribeZonesResponse ¶
func CreateDescribeZonesResponse() (response *DescribeZonesResponse)
CreateDescribeZonesResponse creates a response to parse from DescribeZones response
type Record ¶
type Record struct {
RecordId int `json:"RecordId" xml:"RecordId"`
Rr string `json:"Rr" xml:"Rr"`
Type string `json:"Type" xml:"Type"`
Ttl int `json:"Ttl" xml:"Ttl"`
Priority int `json:"Priority" xml:"Priority"`
Value string `json:"Value" xml:"Value"`
Status string `json:"Status" xml:"Status"`
}
Record is a nested struct in pvtz response
type Records ¶
type Records struct {
Record []Record `json:"Record" xml:"Record"`
}
Records is a nested struct in pvtz response
type Region ¶
type Region struct {
RegionId string `json:"RegionId" xml:"RegionId"`
RegionName string `json:"RegionName" xml:"RegionName"`
LocalName string `json:"LocalName" xml:"LocalName"`
RegionEndpoint string `json:"RegionEndpoint" xml:"RegionEndpoint"`
}
Region is a nested struct in pvtz response
type Regions ¶
type Regions struct {
Region []Region `json:"Region" xml:"Region"`
}
Regions is a nested struct in pvtz response
type RequestDetails ¶
type RequestDetails struct {
ZoneRequestTop []ZoneRequestTop `json:"ZoneRequestTop" xml:"ZoneRequestTop"`
}
RequestDetails is a nested struct in pvtz response
type SetProxyPatternRequest ¶
type SetProxyPatternRequest struct {
*requests.RpcRequest
ProxyPattern string `position:"Query" name:"ProxyPattern"`
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Lang string `position:"Query" name:"Lang"`
}
SetProxyPatternRequest is the request struct for api SetProxyPattern
func CreateSetProxyPatternRequest ¶
func CreateSetProxyPatternRequest() (request *SetProxyPatternRequest)
CreateSetProxyPatternRequest creates a request to invoke SetProxyPattern API
type SetProxyPatternResponse ¶
type SetProxyPatternResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ZoneId string `json:"ZoneId" xml:"ZoneId"`
}
SetProxyPatternResponse is the response struct for api SetProxyPattern
func CreateSetProxyPatternResponse ¶
func CreateSetProxyPatternResponse() (response *SetProxyPatternResponse)
CreateSetProxyPatternResponse creates a response to parse from SetProxyPattern response
type SetZoneRecordStatusRequest ¶
type SetZoneRecordStatusRequest struct {
*requests.RpcRequest
RecordId requests.Integer `position:"Query" name:"RecordId"`
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
Status string `position:"Query" name:"Status"`
}
SetZoneRecordStatusRequest is the request struct for api SetZoneRecordStatus
func CreateSetZoneRecordStatusRequest ¶
func CreateSetZoneRecordStatusRequest() (request *SetZoneRecordStatusRequest)
CreateSetZoneRecordStatusRequest creates a request to invoke SetZoneRecordStatus API
type SetZoneRecordStatusResponse ¶
type SetZoneRecordStatusResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
RecordId int `json:"RecordId" xml:"RecordId"`
Status string `json:"Status" xml:"Status"`
}
SetZoneRecordStatusResponse is the response struct for api SetZoneRecordStatus
func CreateSetZoneRecordStatusResponse ¶
func CreateSetZoneRecordStatusResponse() (response *SetZoneRecordStatusResponse)
CreateSetZoneRecordStatusResponse creates a response to parse from SetZoneRecordStatus response
type UpdateZoneRecordRequest ¶
type UpdateZoneRecordRequest struct {
*requests.RpcRequest
Rr string `position:"Query" name:"Rr"`
RecordId requests.Integer `position:"Query" name:"RecordId"`
UserClientIp string `position:"Query" name:"UserClientIp"`
Lang string `position:"Query" name:"Lang"`
Type string `position:"Query" name:"Type"`
Priority requests.Integer `position:"Query" name:"Priority"`
Ttl requests.Integer `position:"Query" name:"Ttl"`
Value string `position:"Query" name:"Value"`
}
UpdateZoneRecordRequest is the request struct for api UpdateZoneRecord
func CreateUpdateZoneRecordRequest ¶
func CreateUpdateZoneRecordRequest() (request *UpdateZoneRecordRequest)
CreateUpdateZoneRecordRequest creates a request to invoke UpdateZoneRecord API
type UpdateZoneRecordResponse ¶
type UpdateZoneRecordResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
RecordId int `json:"RecordId" xml:"RecordId"`
}
UpdateZoneRecordResponse is the response struct for api UpdateZoneRecord
func CreateUpdateZoneRecordResponse ¶
func CreateUpdateZoneRecordResponse() (response *UpdateZoneRecordResponse)
CreateUpdateZoneRecordResponse creates a response to parse from UpdateZoneRecord response
type UpdateZoneRemarkRequest ¶
type UpdateZoneRemarkRequest struct {
*requests.RpcRequest
UserClientIp string `position:"Query" name:"UserClientIp"`
ZoneId string `position:"Query" name:"ZoneId"`
Remark string `position:"Query" name:"Remark"`
Lang string `position:"Query" name:"Lang"`
}
UpdateZoneRemarkRequest is the request struct for api UpdateZoneRemark
func CreateUpdateZoneRemarkRequest ¶
func CreateUpdateZoneRemarkRequest() (request *UpdateZoneRemarkRequest)
CreateUpdateZoneRemarkRequest creates a request to invoke UpdateZoneRemark API
type UpdateZoneRemarkResponse ¶
type UpdateZoneRemarkResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ZoneId string `json:"ZoneId" xml:"ZoneId"`
}
UpdateZoneRemarkResponse is the response struct for api UpdateZoneRemark
func CreateUpdateZoneRemarkResponse ¶
func CreateUpdateZoneRemarkResponse() (response *UpdateZoneRemarkResponse)
CreateUpdateZoneRemarkResponse creates a response to parse from UpdateZoneRemark response
type Vpc ¶
type Vpc struct {
RegionId string `json:"RegionId" xml:"RegionId"`
VpcName string `json:"VpcName" xml:"VpcName"`
VpcId string `json:"VpcId" xml:"VpcId"`
RegionName string `json:"RegionName" xml:"RegionName"`
ReionId string `json:"ReionId" xml:"ReionId"`
}
Vpc is a nested struct in pvtz response
type VpcRequestTop ¶
type VpcRequestTop struct {
RegionId string `json:"RegionId" xml:"RegionId"`
VpcId string `json:"VpcId" xml:"VpcId"`
TunnelId string `json:"TunnelId" xml:"TunnelId"`
RequestCount int `json:"RequestCount" xml:"RequestCount"`
RegionName string `json:"RegionName" xml:"RegionName"`
}
VpcRequestTop is a nested struct in pvtz response
type VpcRequestTops ¶
type VpcRequestTops struct {
VpcRequestTop []VpcRequestTop `json:"VpcRequestTop" xml:"VpcRequestTop"`
}
VpcRequestTops is a nested struct in pvtz response
type Vpcs ¶
type Vpcs struct {
Vpc []Vpc `json:"Vpc" xml:"Vpc"`
}
Vpcs is a nested struct in pvtz response
type Zone ¶
type Zone struct {
ZoneId string `json:"ZoneId" xml:"ZoneId"`
UpdateTime string `json:"UpdateTime" xml:"UpdateTime"`
ProxyPattern string `json:"ProxyPattern" xml:"ProxyPattern"`
Remark string `json:"Remark" xml:"Remark"`
CreateTimestamp int `json:"CreateTimestamp" xml:"CreateTimestamp"`
RecordCount int `json:"RecordCount" xml:"RecordCount"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
ZoneName string `json:"ZoneName" xml:"ZoneName"`
IsPtr bool `json:"IsPtr" xml:"IsPtr"`
UpdateTimestamp int `json:"UpdateTimestamp" xml:"UpdateTimestamp"`
Vpcs Vpcs `json:"Vpcs" xml:"Vpcs"`
}
Zone is a nested struct in pvtz response
type ZoneRequestTop ¶
type ZoneRequestTop struct {
Time string `json:"Time" xml:"Time"`
RequestCount int `json:"RequestCount" xml:"RequestCount"`
Timestamp int `json:"Timestamp" xml:"Timestamp"`
ZoneName string `json:"ZoneName" xml:"ZoneName"`
}
ZoneRequestTop is a nested struct in pvtz response
type ZoneRequestTops ¶
type ZoneRequestTops struct {
ZoneRequestTop []ZoneRequestTop `json:"ZoneRequestTop" xml:"ZoneRequestTop"`
}
ZoneRequestTops is a nested struct in pvtz response
type ZonesInDescribeZoneVpcTree ¶
type ZonesInDescribeZoneVpcTree struct {
Zone []Zone `json:"Zone" xml:"Zone"`
}
ZonesInDescribeZoneVpcTree is a nested struct in pvtz response
type ZonesInDescribeZones ¶
type ZonesInDescribeZones struct {
Zone []Zone `json:"Zone" xml:"Zone"`
}
ZonesInDescribeZones is a nested struct in pvtz response
Source Files
¶
- add_zone.go
- add_zone_record.go
- bind_zone_vpc.go
- check_zone_name.go
- client.go
- delete_zone.go
- delete_zone_record.go
- describe_change_logs.go
- describe_regions.go
- describe_request_graph.go
- describe_statistic_summary.go
- describe_user_service_status.go
- describe_zone_info.go
- describe_zone_records.go
- describe_zone_vpc_tree.go
- describe_zones.go
- set_proxy_pattern.go
- set_zone_record_status.go
- struct_bind_vpcs.go
- struct_change_log.go
- struct_change_logs.go
- struct_record.go
- struct_records.go
- struct_region.go
- struct_regions.go
- struct_request_details.go
- struct_vpc.go
- struct_vpc_request_top.go
- struct_vpc_request_tops.go
- struct_vpcs.go
- struct_zone.go
- struct_zone_request_top.go
- struct_zone_request_tops.go
- struct_zones_in_describe_zone_vpc_tree.go
- struct_zones_in_describe_zones.go
- update_zone_record.go
- update_zone_remark.go