Documentation
¶
Index ¶
- type BatchGetJobMetricInfoRequest
- type BatchGetJobMetricInfoResponse
- type BatchGetPluginConfigInfoRequest
- type BatchGetPluginConfigInfoResponse
- type Childrens
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) BatchGetJobMetricInfo(request *BatchGetJobMetricInfoRequest) (response *BatchGetJobMetricInfoResponse, err error)
- func (client *Client) BatchGetJobMetricInfoWithCallback(request *BatchGetJobMetricInfoRequest, ...) <-chan int
- func (client *Client) BatchGetJobMetricInfoWithChan(request *BatchGetJobMetricInfoRequest) (<-chan *BatchGetJobMetricInfoResponse, <-chan error)
- func (client *Client) BatchGetPluginConfigInfo(request *BatchGetPluginConfigInfoRequest) (response *BatchGetPluginConfigInfoResponse, err error)
- func (client *Client) BatchGetPluginConfigInfoWithCallback(request *BatchGetPluginConfigInfoRequest, ...) <-chan int
- func (client *Client) BatchGetPluginConfigInfoWithChan(request *BatchGetPluginConfigInfoRequest) (<-chan *BatchGetPluginConfigInfoResponse, <-chan error)
- func (client *Client) GetJobTopology(request *GetJobTopologyRequest) (response *GetJobTopologyResponse, err error)
- func (client *Client) GetJobTopologyWithCallback(request *GetJobTopologyRequest, ...) <-chan int
- func (client *Client) GetJobTopologyWithChan(request *GetJobTopologyRequest) (<-chan *GetJobTopologyResponse, <-chan error)
- type DataInBatchGetJobMetricInfo
- type DataInBatchGetPluginConfigInfo
- type DataInGetJobTopology
- type GetJobTopologyRequest
- type GetJobTopologyResponse
- type Job
- type Parents
- type Plugin
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BatchGetJobMetricInfoRequest ¶
type BatchGetJobMetricInfoRequest struct {
*requests.RpcRequest
JobInfos string `position:"Query" name:"JobInfos"`
}
BatchGetJobMetricInfoRequest is the request struct for api BatchGetJobMetricInfo
func CreateBatchGetJobMetricInfoRequest ¶
func CreateBatchGetJobMetricInfoRequest() (request *BatchGetJobMetricInfoRequest)
CreateBatchGetJobMetricInfoRequest creates a request to invoke BatchGetJobMetricInfo API
type BatchGetJobMetricInfoResponse ¶
type BatchGetJobMetricInfoResponse struct {
*responses.BaseResponse
Code int `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
RequestId string `json:"RequestId" xml:"RequestId"`
Data []Job `json:"Data" xml:"Data"`
}
BatchGetJobMetricInfoResponse is the response struct for api BatchGetJobMetricInfo
func CreateBatchGetJobMetricInfoResponse ¶
func CreateBatchGetJobMetricInfoResponse() (response *BatchGetJobMetricInfoResponse)
CreateBatchGetJobMetricInfoResponse creates a response to parse from BatchGetJobMetricInfo response
type BatchGetPluginConfigInfoRequest ¶
type BatchGetPluginConfigInfoRequest struct {
*requests.RpcRequest
PluginInfos string `position:"Query" name:"PluginInfos"`
}
BatchGetPluginConfigInfoRequest is the request struct for api BatchGetPluginConfigInfo
func CreateBatchGetPluginConfigInfoRequest ¶
func CreateBatchGetPluginConfigInfoRequest() (request *BatchGetPluginConfigInfoRequest)
CreateBatchGetPluginConfigInfoRequest creates a request to invoke BatchGetPluginConfigInfo API
type BatchGetPluginConfigInfoResponse ¶
type BatchGetPluginConfigInfoResponse struct {
*responses.BaseResponse
Code int `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
RequestId string `json:"RequestId" xml:"RequestId"`
Data []Plugin `json:"Data" xml:"Data"`
}
BatchGetPluginConfigInfoResponse is the response struct for api BatchGetPluginConfigInfo
func CreateBatchGetPluginConfigInfoResponse ¶
func CreateBatchGetPluginConfigInfoResponse() (response *BatchGetPluginConfigInfoResponse)
CreateBatchGetPluginConfigInfoResponse creates a response to parse from BatchGetPluginConfigInfo response
type Childrens ¶
type Childrens struct {
Children []string `json:"Children" xml:"Children"`
}
Childrens is a nested struct in teslastream response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://help.aliyun.com/document_detail/66217.html
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://help.aliyun.com/document_detail/66223.html
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://help.aliyun.com/document_detail/66222.html
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair attention: rsa key pair auth is only Japan regions available
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://help.aliyun.com/document_detail/66222.html
func (*Client) BatchGetJobMetricInfo ¶
func (client *Client) BatchGetJobMetricInfo(request *BatchGetJobMetricInfoRequest) (response *BatchGetJobMetricInfoResponse, err error)
BatchGetJobMetricInfo invokes the teslastream.BatchGetJobMetricInfo API synchronously api document: https://help.aliyun.com/api/teslastream/batchgetjobmetricinfo.html
func (*Client) BatchGetJobMetricInfoWithCallback ¶
func (client *Client) BatchGetJobMetricInfoWithCallback(request *BatchGetJobMetricInfoRequest, callback func(response *BatchGetJobMetricInfoResponse, err error)) <-chan int
BatchGetJobMetricInfoWithCallback invokes the teslastream.BatchGetJobMetricInfo API asynchronously api document: https://help.aliyun.com/api/teslastream/batchgetjobmetricinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) BatchGetJobMetricInfoWithChan ¶
func (client *Client) BatchGetJobMetricInfoWithChan(request *BatchGetJobMetricInfoRequest) (<-chan *BatchGetJobMetricInfoResponse, <-chan error)
BatchGetJobMetricInfoWithChan invokes the teslastream.BatchGetJobMetricInfo API asynchronously api document: https://help.aliyun.com/api/teslastream/batchgetjobmetricinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) BatchGetPluginConfigInfo ¶
func (client *Client) BatchGetPluginConfigInfo(request *BatchGetPluginConfigInfoRequest) (response *BatchGetPluginConfigInfoResponse, err error)
BatchGetPluginConfigInfo invokes the teslastream.BatchGetPluginConfigInfo API synchronously api document: https://help.aliyun.com/api/teslastream/batchgetpluginconfiginfo.html
func (*Client) BatchGetPluginConfigInfoWithCallback ¶
func (client *Client) BatchGetPluginConfigInfoWithCallback(request *BatchGetPluginConfigInfoRequest, callback func(response *BatchGetPluginConfigInfoResponse, err error)) <-chan int
BatchGetPluginConfigInfoWithCallback invokes the teslastream.BatchGetPluginConfigInfo API asynchronously api document: https://help.aliyun.com/api/teslastream/batchgetpluginconfiginfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) BatchGetPluginConfigInfoWithChan ¶
func (client *Client) BatchGetPluginConfigInfoWithChan(request *BatchGetPluginConfigInfoRequest) (<-chan *BatchGetPluginConfigInfoResponse, <-chan error)
BatchGetPluginConfigInfoWithChan invokes the teslastream.BatchGetPluginConfigInfo API asynchronously api document: https://help.aliyun.com/api/teslastream/batchgetpluginconfiginfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) GetJobTopology ¶
func (client *Client) GetJobTopology(request *GetJobTopologyRequest) (response *GetJobTopologyResponse, err error)
GetJobTopology invokes the teslastream.GetJobTopology API synchronously api document: https://help.aliyun.com/api/teslastream/getjobtopology.html
func (*Client) GetJobTopologyWithCallback ¶
func (client *Client) GetJobTopologyWithCallback(request *GetJobTopologyRequest, callback func(response *GetJobTopologyResponse, err error)) <-chan int
GetJobTopologyWithCallback invokes the teslastream.GetJobTopology API asynchronously api document: https://help.aliyun.com/api/teslastream/getjobtopology.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) GetJobTopologyWithChan ¶
func (client *Client) GetJobTopologyWithChan(request *GetJobTopologyRequest) (<-chan *GetJobTopologyResponse, <-chan error)
GetJobTopologyWithChan invokes the teslastream.GetJobTopology API asynchronously api document: https://help.aliyun.com/api/teslastream/getjobtopology.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type DataInBatchGetJobMetricInfo ¶
type DataInBatchGetJobMetricInfo struct {
Job []Job `json:"Job" xml:"Job"`
}
DataInBatchGetJobMetricInfo is a nested struct in teslastream response
type DataInBatchGetPluginConfigInfo ¶
type DataInBatchGetPluginConfigInfo struct {
Plugin []Plugin `json:"plugin" xml:"plugin"`
}
DataInBatchGetPluginConfigInfo is a nested struct in teslastream response
type DataInGetJobTopology ¶
type DataInGetJobTopology struct {
Job []Job `json:"Job" xml:"Job"`
}
DataInGetJobTopology is a nested struct in teslastream response
type GetJobTopologyRequest ¶
type GetJobTopologyRequest struct {
*requests.RpcRequest
JobName string `position:"Query" name:"JobName"`
}
GetJobTopologyRequest is the request struct for api GetJobTopology
func CreateGetJobTopologyRequest ¶
func CreateGetJobTopologyRequest() (request *GetJobTopologyRequest)
CreateGetJobTopologyRequest creates a request to invoke GetJobTopology API
type GetJobTopologyResponse ¶
type GetJobTopologyResponse struct {
*responses.BaseResponse
Code int `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
RequestId string `json:"RequestId" xml:"RequestId"`
Data []Job `json:"Data" xml:"Data"`
}
GetJobTopologyResponse is the response struct for api GetJobTopology
func CreateGetJobTopologyResponse ¶
func CreateGetJobTopologyResponse() (response *GetJobTopologyResponse)
CreateGetJobTopologyResponse creates a response to parse from GetJobTopology response
type Job ¶
type Job struct {
Text string `json:"Text" xml:"Text"`
TpsOut int `json:"TpsOut" xml:"TpsOut"`
CpuUsed float64 `json:"CpuUsed" xml:"CpuUsed"`
Priority string `json:"Priority" xml:"Priority"`
TpsIn int `json:"TpsIn" xml:"TpsIn"`
Nickname string `json:"Nickname" xml:"Nickname"`
CpuRequest int `json:"CpuRequest" xml:"CpuRequest"`
MemUsed float64 `json:"MemUsed" xml:"MemUsed"`
PluginRelation string `json:"PluginRelation" xml:"PluginRelation"`
JobUniqKey string `json:"JobUniqKey" xml:"JobUniqKey"`
Delay int `json:"Delay" xml:"Delay"`
MemRequest int `json:"MemRequest" xml:"MemRequest"`
Type string `json:"Type" xml:"Type"`
Parents []string `json:"Parents" xml:"Parents"`
Childrens []string `json:"Childrens" xml:"Childrens"`
}
Job is a nested struct in teslastream response